#[repr(u8)]pub enum AdcActive {
NOT_ACTIVE = 0,
BUSY = 1,
}Variants
NOT_ACTIVE = 0
ADC is idle. There are no pending triggers to service and no active commands are being processed.
BUSY = 1
ADC is processing a conversion, running through the power-up delay, or servicing a trigger.
Implementations