nxp-pac

Crates

git

Versions

mcxn947_cm33_core0

Flavors

TcompFlag

Enum TcompFlag 

#[repr(u8)]
pub enum TcompFlag {
Show 16 variants NO_TRIGGER = 0, BIT0_MEANS_TRIGGER_0_COMPLETED = 1, BIT1_MEANS_TRIGGER_1_COMPLETED = 2, SET_BITS_INDICATE_TRIGGER_X_COMPLETED_3 = 3, SET_BITS_INDICATE_TRIGGER_X_COMPLETED_4 = 4, SET_BITS_INDICATE_TRIGGER_X_COMPLETED_5 = 5, SET_BITS_INDICATE_TRIGGER_X_COMPLETED_6 = 6, SET_BITS_INDICATE_TRIGGER_X_COMPLETED_7 = 7, SET_BITS_INDICATE_TRIGGER_X_COMPLETED_8 = 8, SET_BITS_INDICATE_TRIGGER_X_COMPLETED_9 = 9, _RESERVED_a = 10, _RESERVED_b = 11, _RESERVED_c = 12, _RESERVED_d = 13, _RESERVED_e = 14, ALL_BITS_SET_INDICATE_ALL_TRIGGERS_COMPLETED = 15,
}

Variants



NO_TRIGGER = 0

No triggers have been completed. Trigger completion interrupts are disabled.



BIT0_MEANS_TRIGGER_0_COMPLETED = 1

Trigger 0 has been completed and trigger 0 has enabled completion interrupts.



BIT1_MEANS_TRIGGER_1_COMPLETED = 2

Trigger 1 has been completed and trigger 1 has enabled completion interrupts.



SET_BITS_INDICATE_TRIGGER_X_COMPLETED_3 = 3

Associated trigger sequence has completed and has enabled completion interrupts.



SET_BITS_INDICATE_TRIGGER_X_COMPLETED_4 = 4

Associated trigger sequence has completed and has enabled completion interrupts.



SET_BITS_INDICATE_TRIGGER_X_COMPLETED_5 = 5

Associated trigger sequence has completed and has enabled completion interrupts.



SET_BITS_INDICATE_TRIGGER_X_COMPLETED_6 = 6

Associated trigger sequence has completed and has enabled completion interrupts.



SET_BITS_INDICATE_TRIGGER_X_COMPLETED_7 = 7

Associated trigger sequence has completed and has enabled completion interrupts.



SET_BITS_INDICATE_TRIGGER_X_COMPLETED_8 = 8

Associated trigger sequence has completed and has enabled completion interrupts.



SET_BITS_INDICATE_TRIGGER_X_COMPLETED_9 = 9

Associated trigger sequence has completed and has enabled completion interrupts.



_RESERVED_a = 10



_RESERVED_b = 11



_RESERVED_c = 12



_RESERVED_d = 13



_RESERVED_e = 14



ALL_BITS_SET_INDICATE_ALL_TRIGGERS_COMPLETED = 15

Every trigger sequence has been completed and every trigger has enabled completion interrupts.

Implementations

Source

impl TcompFlag

pub const fn from_bits(val: u8) -> TcompFlag

pub const fn to_bits(self) -> u8