#[repr(u8)]pub enum Tprictrl {
ABORT_CURRENT_ON_PRIORITY = 0,
FINISH_CURRENT_ON_PRIORITY = 1,
FINISH_SEQUENCE_ON_PRIORITY = 2,
_RESERVED_3 = 3,
}Variants
ABORT_CURRENT_ON_PRIORITY = 0
Current conversion is aborted and the new command specified by the trigger is started.
FINISH_CURRENT_ON_PRIORITY = 1
Current command is stopped after completing the current conversion. If averaging is enabled, the averaging loop is completed. CMDHn[LOOP] is ignored and the higher-priority trigger is serviced.
FINISH_SEQUENCE_ON_PRIORITY = 2
Current command is completed (averaging, looping, compare) before servicing the higher-priority trigger.
_RESERVED_3 = 3
Implementations